Index: apps/app_festival.c
===================================================================
--- apps/app_festival.c	(revision 46328)
+++ apps/app_festival.c	(working copy)
@@ -73,7 +73,7 @@
 {
     /* Receive file (probably a waveform file) from socket using   */
     /* Festival key stuff technique, but long winded I know, sorry */
-    /* but will receive any file without closeing the stream or    */
+    /* but will receive any file without closing the stream or    */
     /* using OOB data                                              */
     static char *file_stuff_key = "ft_StUfF_key"; /* must == Festival's key */
     char *buff;
Index: apps/app_alarmreceiver.c
===================================================================
--- apps/app_alarmreceiver.c	(revision 46328)
+++ apps/app_alarmreceiver.c	(working copy)
@@ -660,7 +660,7 @@
 		return -1;
 	}
 
-	/* Set default values for this invokation of the application */
+	/* Set default values for this invocation of the application */
 	
 	ast_copy_string(signalling_type, ADEMCO_CONTACT_ID, sizeof(signalling_type));
 
Index: apps/app_rpt.c
===================================================================
--- apps/app_rpt.c	(revision 46328)
+++ apps/app_rpt.c	(working copy)
@@ -766,7 +766,7 @@
 } ;
 
 /*
-* Forward decl's - these suppress compiler warnings when funcs coded further down the file than thier invokation
+* Forward decl's - these suppress compiler warnings when funcs coded further down the file than their invocation
 */
 
 static int setrbi(struct rpt *myrpt);
@@ -1540,7 +1540,7 @@
 	
 	dottime = 900 / speed;
 	
-	/* Establish timing releationships */
+	/* Establish timing relationships */
 	
 	dashtime = 3 * dottime;
 	intralettertime = dottime;
@@ -7238,7 +7238,7 @@
 				service_scan(myrpt);
 			}
 		}
-		if (who == chan) { /* if it was a read from incomming */
+		if (who == chan) { /* if it was a read from incoming */
 			f = ast_read(chan);
 			if (!f) {
 				if (debug)
Index: apps/app_meetme.c
===================================================================
--- apps/app_meetme.c	(revision 46328)
+++ apps/app_meetme.c	(working copy)
@@ -364,7 +364,7 @@
 	ASTOBJ_CONTAINER_COMPONENTS(struct ast_sla_station);
 };
 
-/*! SLA - Shared Line Apperance object. These consist of one trunk (outbound line)
+/*! SLA - Shared Line Appearance object. These consist of one trunk (outbound line)
 	and stations that receive incoming calls and place outbound calls over the trunk 
 */
 struct ast_sla {
@@ -1090,7 +1090,7 @@
 	time(&user->jointime);
 
 	if (conf->locked && (!(confflags & CONFFLAG_ADMIN))) {
-		/* Sorry, but this confernce is locked! */	
+		/* Sorry, but this conference is locked! */	
 		if (!ast_streamfile(chan, "conf-locked", chan->language))
 			ast_waitstream(chan, "");
 		goto outrun;
Index: apps/app_sms.c
===================================================================
--- apps/app_sms.c	(revision 46328)
+++ apps/app_sms.c	(working copy)
@@ -542,7 +542,7 @@
 		}
 	}
 	while (l--)
-		*o++ = *i++;	  /* not to UTF-8 as explicitely 8 bit coding in DCS */
+		*o++ = *i++;	  /* not to UTF-8 as explicitly 8 bit coding in DCS */
 	*udl = (o - ud);
 }
 
Index: main/manager.c
===================================================================
--- main/manager.c	(revision 46328)
+++ main/manager.c	(working copy)
@@ -137,7 +137,7 @@
 	int inuse;		/*!< number of HTTP sessions using this entry */
 	int needdestroy;	/*!< Whether an HTTP session should be destroyed */
 	pthread_t waiting_thread;	/*!< Whether an HTTP session has someone waiting on events */
-	unsigned long managerid;	/*!< Unique manager identifer, 0 for AMI sessions */
+	unsigned long managerid;	/*!< Unique manager identifier, 0 for AMI sessions */
 	time_t sessiontimeout;	/*!< Session timeout if HTTP */
 	struct ast_dynamic_str *outputstr;	/*!< Output from manager interface */
 	char username[80];	/*!< Logged in username */
Index: main/rtp.c
===================================================================
--- main/rtp.c	(revision 46328)
+++ main/rtp.c	(working copy)
@@ -662,7 +662,7 @@
 	}
 	if ((!rtp->resp && power) || (rtp->resp && (rtp->resp != resp))) {
 		rtp->resp = resp;
-		/* Why we should care on DTMF compensation at receiption? */
+		/* Why we should care on DTMF compensation at reception? */
 		if (!ast_test_flag(rtp, FLAG_DTMF_COMPENSATE)) {
 			f = send_dtmf(rtp, AST_FRAME_DTMF_BEGIN);
 			rtp->dtmfduration = 0;
@@ -2311,7 +2311,7 @@
 	return res;
 }
 
-/*! \brief Send RTCP recepient's report */
+/*! \brief Send RTCP recipient's report */
 static int ast_rtcp_write_rr(void *data)
 {
 	struct ast_rtp *rtp = data;
Index: main/say.c
===================================================================
--- main/say.c	(revision 46328)
+++ main/say.c	(working copy)
@@ -3614,7 +3614,7 @@
 
 /* TODO: this probably is not the correct format for doxygen remarks */
 
-/** ast_say_date_with_format_he Say formmated date in Hebrew
+/** ast_say_date_with_format_he Say formatted date in Hebrew
  *
  * \ref ast_say_date_with_format_en for the details of the options 
  *
Index: main/pbx.c
===================================================================
--- main/pbx.c	(revision 46328)
+++ main/pbx.c	(working copy)
@@ -3022,7 +3022,7 @@
 	return RESULT_SUCCESS;
 }
 
-/*! \brief  handle_show_hints: CLI support for listing registred dial plan hints */
+/*! \brief  handle_show_hints: CLI support for listing registered dial plan hints */
 static int handle_show_hints(int fd, int argc, char *argv[])
 {
 	struct ast_hint *hint;
@@ -3054,7 +3054,7 @@
 	return RESULT_SUCCESS;
 }
 
-/*! \brief  handle_show_switches: CLI support for listing registred dial plan switches */
+/*! \brief  handle_show_switches: CLI support for listing registered dial plan switches */
 static int handle_show_switches(int fd, int argc, char *argv[])
 {
 	struct ast_switch *sw;
@@ -4634,7 +4634,7 @@
 	}
 
 	/* allocation of the cdr was successful */
-	ast_cdr_init(chan->cdr, chan);  /* initilize our channel's cdr */
+	ast_cdr_init(chan->cdr, chan);  /* initialize our channel's cdr */
 	ast_cdr_start(chan->cdr);       /* record the start and stop time */
 	ast_cdr_end(chan->cdr);
 	ast_cdr_failed(chan->cdr);      /* set the status to failed */
@@ -4672,7 +4672,7 @@
 					goto outgoing_exten_cleanup;
 				}
 				/* allocation of the cdr was successful */
-				ast_cdr_init(chan->cdr, chan);  /* initilize our channel's cdr */
+				ast_cdr_init(chan->cdr, chan);  /* initialize our channel's cdr */
 				ast_cdr_start(chan->cdr);
 			}
 			if (chan->_state == AST_STATE_UP) {
@@ -4845,7 +4845,7 @@
 					goto outgoing_app_cleanup;
 				}
 				/* allocation of the cdr was successful */
-				ast_cdr_init(chan->cdr, chan);  /* initilize our channel's cdr */
+				ast_cdr_init(chan->cdr, chan);  /* initialize our channel's cdr */
 				ast_cdr_start(chan->cdr);
 			}
 			ast_set_variables(chan, vars);

Index: apps/app_voicemail.c
===================================================================
--- apps/app_voicemail.c	(revision 46328)
+++ apps/app_voicemail.c	(working copy)
@@ -1790,7 +1790,7 @@
 static void prep_email_sub_vars(struct ast_channel *ast, struct ast_vm_user *vmu, int msgnum, char *context, char *mailbox, char *cidnum, char *cidname, char *dur, char *date, char *passdata, size_t passdatasize, const char *category)
 {
 	char callerid[256];
-	/* Prepare variables for substition in email body and subject */
+	/* Prepare variables for substitution in email body and subject */
 	pbx_builtin_setvar_helper(ast, "VM_NAME", vmu->fullname);
 	pbx_builtin_setvar_helper(ast, "VM_DUR", dur);
 	snprintf(passdata, passdatasize, "%d", msgnum);
@@ -2901,7 +2901,7 @@
 		msgnum = newmsgs + oldmsgs;
 		ast_log(LOG_NOTICE, "Messagecount set to %d\n",msgnum);
 		snprintf(fn, sizeof(fn), "%s/imap/msg%s%04d", VM_SPOOL_DIR, vmu->mailbox, msgnum);
-		/* set variable for compatability */
+		/* set variable for compatibility */
 		pbx_builtin_setvar_helper(chan, "VM_MESSAGEFILE", "IMAP_STORAGE");
 
 		/* Check if mailbox is full */
@@ -5908,7 +5908,7 @@
 
 static int vm_execmain(struct ast_channel *chan, void *data)
 {
-	/* XXX This is, admittedly, some pretty horrendus code.  For some
+	/* XXX This is, admittedly, some pretty horrendous code.  For some
 	   reason it just seemed a lot easier to do with GOTO's.  I feel
 	   like I'm back in my GWBASIC days. XXX */
 	int res=-1;
@@ -6429,7 +6429,7 @@
 #endif
 			mail_expunge(vms.mailstream);
 	}
-	/*  before we delete the state, we should copy pertainent info
+	/*  before we delete the state, we should copy pertinent info
 	 *  back to the persistent model */
 	vmstate_delete(&vms);
 #endif
@@ -7082,14 +7082,14 @@
 		}
 		ast_set2_flag((&globalflags), ast_true(astreview), VM_REVIEW);	
 
 		/*Temperary greeting reminder */
 		if (!(asttempgreetwarn = ast_variable_retrieve(cfg, "general", "tempgreetwarn"))) {
 			if (option_debug)
-				ast_log(LOG_DEBUG, "VM Temperary Greeting Reminder Option disabled globally\n");
+				ast_log(LOG_DEBUG, "VM Temporary Greeting Reminder Option disabled globally\n");
 			asttempgreetwarn = "no";
 		} else {
 			if (option_debug)
-				ast_log(LOG_DEBUG, "VM Temperary Greeting Reminder Option enabled globally\n");
+				ast_log(LOG_DEBUG, "VM Temporary Greeting Reminder Option enabled globally\n");
 		}
 		ast_set2_flag((&globalflags), ast_true(asttempgreetwarn), VM_TEMPGREETWARN);
 
@@ -8459,7 +8459,7 @@
 	struct vmstate *vc, *vf = NULL, *vl = NULL;
 	struct vm_state *altvms;
 
-	/* If interactive, we should copy pertainent info
+	/* If interactive, we should copy pertinent info
 	   back to the persistent state (to make update immediate) */
 	if (vms->interactive == 1) {
 		altvms = vms->persist_vms;
@@ -7082,14 +7082,14 @@
 		ast_set2_flag((&globalflags), ast_true(astreview), VM_REVIEW);	
 
-		/*Temperary greeting reminder */
+		/*Temporary greeting reminder */
 		if (!(asttempgreetwarn = ast_variable_retrieve(cfg, "general", "tempgreetwarn"))) {
 			if (option_debug)
Index: apps/app_osplookup.c
===================================================================
--- apps/app_osplookup.c	(revision 46328)
+++ apps/app_osplookup.c	(working copy)
@@ -131,7 +131,7 @@
 /* OSP Module Global Variables */
 AST_MUTEX_DEFINE_STATIC(osplock);				/* Lock of OSP provider list */
 static int osp_initialized = 0;					/* Init flag */
-static int osp_hardware = 0;					/* Hardware accelleration flag */
+static int osp_hardware = 0;					/* Hardware acceleration flag */
 static struct osp_provider* ospproviders = NULL;		/* OSP provider list */
 static unsigned int osp_tokenformat = TOKEN_ALGO_SIGNED;	/* Token format supported */
 
@@ -1484,7 +1484,7 @@
 		t = ast_variable_retrieve(cfg, OSP_GENERAL_CAT, "accelerate");
 		if (t && ast_true(t)) {
 			if ((error = OSPPInit(1)) != OSPC_ERR_NO_ERROR) {
-				ast_log(LOG_WARNING, "OSP: Unable to enable hardware accelleration\n");
+				ast_log(LOG_WARNING, "OSP: Unable to enable hardware acceleration\n");
 				OSPPInit(0);
 			} else {
 				osp_hardware = 1;